embassy-mcxa

Crates

git

Versions

mcx-a256

Flavors

Compare

Enum Compare 

pub enum Compare {
    Disabled,
    StoreIf(CompareFunction),
    SkipUntil(CompareFunction),
}
Select the compare functionality of the ADC

Variants



Disabled

Do not perform compare operation. Always store the conversion result to the FIFO.



StoreIf(CompareFunction)

Store conversion result to FIFO at end of averaging only if compare is true. If compare is false do not store the result to the FIFO. In either the true or false condition, the LOOP setting is considered and increments the LOOP counter before deciding whether the current command has completed or additional LOOP iterations are required.



SkipUntil(CompareFunction)

Store conversion result to FIFO at end of averaging only if compare is true. Once the true condition is found the LOOP setting is considered and increments the LOOP counter before deciding whether the current command has completed or additional LOOP iterations are required. If the compare is false do not store the result to the FIFO. The conversion is repeated without consideration of LOOP setting and does not increment the LOOP counter.