embassy-mcxa

Crates

git

Versions

mcx-a256

Flavors

CompareFunction

Enum CompareFunction 

pub enum CompareFunction {
    OutsideRange(RangeInclusive<u16>),
    LessThan(u16),
    GreaterThan(u16),
    InsideRange(RangeInclusive<u16>),
}
Type that specifies the function used for the compare featue of the ADC.

This determines the CVL & CVH values.

Variants



OutsideRange(RangeInclusive<u16>)

The compare will succeed when the value is not in the specified range



LessThan(u16)

The compare will succeed when the value is lower than the specified value



GreaterThan(u16)

The compare will succeed when the value is higher than the specified value



InsideRange(RangeInclusive<u16>)

The compare will succeed when the value is in the specified range