pub enum Error {
FifoEmpty,
FifoPending,
InvalidConfig,
TooManyCommands,
TooManyTriggers,
NoTrigger,
ClockSetup(ClockError),
}Expand description
ADC Error types
Variants
FifoEmpty
FIFO is empty, no conversion result available
FifoPending
FIFO is empty, but the adc is active and a new conversion will be ready soon
InvalidConfig
Invalid configuration
TooManyCommands
Too many commands
TooManyTriggers
Too many triggers
NoTrigger
Tried to call a trigger that was not configured
ClockSetup(ClockError)
Clock configuration error.