pub struct Command<'a, T> { /* private fields */ }Expand description
A command that can be executed by the ADC
Implementations
Sourceimpl<'a, T: Instance> Command<'a, T>
impl<'a, T: Instance> Command<'a, T>
Sourcepub fn new_single(
channel: Peri<'a, impl Into<AnyAdcPin<T>> + PeripheralType>,
config: CommandConfig,
) -> Self
pub fn new_single( channel: Peri<'a, impl Into<AnyAdcPin<T>> + PeripheralType>, config: CommandConfig, ) -> Self
A command that does one conversion on a channel
Sourcepub fn new_looping(
channel: Peri<'a, impl Into<AnyAdcPin<T>> + PeripheralType>,
num_loops: u8,
config: CommandConfig,
) -> Result<Self, Error>
pub fn new_looping( channel: Peri<'a, impl Into<AnyAdcPin<T>> + PeripheralType>, num_loops: u8, config: CommandConfig, ) -> Result<Self, Error>
A command that does multiple conversions on a channel.
num_loops: The amount of times the command is run. Range:1..=16
Sourcepub fn new_multichannel(
channels: &'a [Peri<'a, AnyAdcPin<T>>],
config: CommandConfig,
) -> Result<Self, Error>
pub fn new_multichannel( channels: &'a [Peri<'a, AnyAdcPin<T>>], config: CommandConfig, ) -> Result<Self, Error>
A command that does multiple conversions on multiple channels