embassy-mcxa

Crates

git

Versions

mcx-a256

Flavors

CommandConfig

Struct CommandConfig 

pub struct CommandConfig {
    pub chained_command: Option<CommandId>,
    pub averaging: Avgs,
    pub sample_time: Sts,
    pub compare: Compare,
    pub resolution: Mode,
    pub wait_for_trigger: bool,
}
Configuration for a conversion command

Fields

chained_command: Option<CommandId>

The command that will be executed next.

If None, conversion will end

averaging: Avgs

The averaging done on a conversion

sample_time: Sts

The sampling time of a conversion

compare: Compare

The compare function being used

resolution: Mode

The resolution of a conversion

wait_for_trigger: bool

When false, the command will not wait for a trigger once the command sequence has been started. When true, a trigger is required before the command is started.